EMVA1288
========

The EMVA1288 module is a Python package to process and print results of an
EMVA tests.

This is the reference implementation for the EMVA1288 Standard for
Measurement and Presentation of Specifications for Machine Vision
Sensors and Cameras.

Please visit `Emva1288
Website <http://www.emva.org/cms/index.php?idcat=26>`__ for information
and latest releases of the standard.

Documentation
-------------

The whole module documentation is hosted on `this website
<http://emva1288.readthedocs.io/en/latest/>`__
There, one can find installation details of the EMVA1288 module
and the api documentation with tutorials on how to
use the module.
